summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--power/mt8183.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/power/mt8183.c b/power/mt8183.c
index 47b7a8b3e1..56aeaadb7a 100644
--- a/power/mt8183.c
+++ b/power/mt8183.c
@@ -391,8 +391,8 @@ enum power_state power_handle_state(enum power_state state)
gpio_set_level(GPIO_PMIC_EN_ODL, 1);
}
- /* If EC is in RW, or has already booted once, reboot to RO. */
- if (system_get_image_copy() != EC_IMAGE_RO || booted) {
+ /* If EC jumped, or has already booted once, reboot to RO. */
+ if (system_jumped_to_this_image() || booted) {
/*
* TODO(b:109850749): How quickly does the EC come back
* up? Would IN_PGOOD_PMIC be ready by the time we are